#!/usr/bin/env python

# vibrance.py
#
# License: GPLv3
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY# without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# To view a copy of the GNU General Public License
# visit: http://www.gnu.org/licenses/gpl.html
#
# ------------
#| Change Log |
# ------------
# Version 1  03/07/2022
#
#import Image
from gimpfu import *
def python_vibrance(image, layer):
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()
	
	if not pdb.gimp_selection_is_empty(image):																#check for existing selection
		old_select = pdb.gimp_selection_save(image)															#if exists - save to channel
	pdb.gimp_selection_none(image)																			#remove any existing selection
	
	layerNew = pdb.gimp_layer_new_from_drawable(layer, image)
	pdb.gimp_image_insert_layer(image, layerNew, None, 0)
	
	width   = image.width
	height  = image.height
	type    = RGB_IMAGE
	opacity = 100
	mode    = NORMAL_MODE
	
	mask = pdb.gimp_layer_create_mask(layerNew, ADD_MASK_WHITE)												#add mask
	pdb.gimp_layer_add_mask(layerNew, mask)
	pdb.gimp_item_set_name(layerNew,"Low Sat.")
																										
	decomposed_image, not_used1, not_used2, not_used3 = pdb.plug_in_decompose(image, layerNew, "HSV", 1)	#decompose image HSV mode
	
	display = pdb.gimp_display_new(decomposed_image)
	
	saturation_layer = decomposed_image.layers[1]
	
	pdb.gimp_drawable_levels_stretch(saturation_layer)														#stretch mask to increase it's effect

	pdb.gimp_selection_all(decomposed_image)
	pdb.gimp_edit_copy(saturation_layer)																	#copy to buffer to use later
	
	pdb.gimp_display_delete(display)	
	
	floating_sel = pdb.gimp_edit_paste(saturation_layer, TRUE)												#copy saturation to layer_copy
	
	floating_sel=pdb.gimp_edit_paste(mask, TRUE)															#paste into mask										
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	layer_add = pdb.gimp_layer_new_from_drawable(layerNew, image)
	pdb.gimp_image_insert_layer(image, layer_add, None, 0)
	pdb.gimp_item_set_name(layer_add,"High Sat.")
	
	pdb.gimp_layer_set_edit_mask(layer_add, TRUE)															#make mask active
	
	pdb.gimp_drawable_invert(mask, FALSE)																	#invert mask
	
	pdb.gimp_layer_set_edit_mask(layer_add, FALSE) 															#make layer active
	
	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()

register(
	"python_vibrance",
	"Vibrance",
	"Vibrance",
	"David Marsden",
	"David Marsden",
	"July 2022",
	"<Image>/Python-Fu/Vibrance...",
	"RGB*", 
	[],
	[],
	python_vibrance)
main()
